==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/StockChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StockChangedEventArgsDescription } from "./StockChangedEventArgsDescription";
/**
 * @hidden
 */
export let StockChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class StockChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (StockChangedEventArgsDescriptionMetadata.a == null) {
                StockChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StockChangedEventArgsDescriptionMetadata.c(StockChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(StockChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(StockChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("AddedSymbols", "Array:string");
            a.item("RemovedSymbols", "Array:string");
        }
        static d(a) {
            StockChangedEventArgsDescriptionMetadata.b(a);
            a.aa("StockChangedEventArgs", () => new StockChangedEventArgsDescription());
            a.z("StockChangedEventArgs", StockChangedEventArgsDescriptionMetadata.a);
        }
    }
    StockChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(StockChangedEventArgsDescriptionMetadata, 'StockChangedEventArgsDescriptionMetadata');
    StockChangedEventArgsDescriptionMetadata.a = null;
    return StockChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/StockChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StockChangedEventArgsDescription } from "./StockChangedEventArgsDescription";
/**
 * @hidden
 */
export let StockChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class StockChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (StockChangedEventArgsDescriptionMetadata.a == null) {
                StockChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StockChangedEventArgsDescriptionMetadata.c(StockChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(StockChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(StockChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("AddedSymbols", "Array:string");
            a.item("RemovedSymbols", "Array:string");
        }
        static d(a) {
            StockChangedEventArgsDescriptionMetadata.b(a);
            a.ac("StockChangedEventArgs", () => new StockChangedEventArgsDescription());
            a.ab("StockChangedEventArgs", StockChangedEventArgsDescriptionMetadata.a);
        }
    }
    StockChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(StockChangedEventArgsDescriptionMetadata, 'StockChangedEventArgsDescriptionMetadata');
    StockChangedEventArgsDescriptionMetadata.a = null;
    return StockChangedEventArgsDescriptionMetadata;
})();
